@@ -2,7 +2,14 @@ class Config:
 
     path = None
 
+    sources = ["koha_api", "db"]
+
+    source = None
+
     config = {
+        "koha_api": {
+            "url": None
+        },
         "db": {
             "host": None,
             "user": None,
