@@ -2,17 +2,19 @@ import sys
 import click
 
 from loguru import logger
+
+from src.core.Config import Config
 from src.commands.SyncKohaRowsCommand import SyncKohaRowsCommand
 from src.commands.LoadConfigFileCommand import LoadConfigFileCommand
 from src.commands.ValidateApiCommand import ValidateApiCommand
 from src.commands.ValidateKohaDBCommand import ValidateKohaDBCommand
 
 
-koha_sync_version = '1.1.2'
+koha_sync_version = '1.2.0'
 
 
 @click.command()
-@click.option('-c', '--config-file', 'config_file', required=True, help="path to configuration file")
+@click.option('-c', '--config-file', 'config_file', required=True, help="path to config file [db] or [Koha_api]")
 @click.option('-v', '--verbose', 'verbosity', count=True, help="activate verbosity output")
 @click.option('-V', '--version', 'version', is_flag=True, help="print current cli version and stops execution")
 @click.option('-r', '--run-once', 'run_once', is_flag=True, help="synchronize once and stops execution")
@@ -30,7 +32,8 @@ def main(config_file, verbosity, run_once, test, version):
     ValidateApiCommand().execute()
 
     # validate Koha DB availability
-    ValidateKohaDBCommand().execute()
+    if Config.source == 'db':
+        ValidateKohaDBCommand().execute()
 
     # synchronize koha registries
     while True:
